function[aapR]=abs_approx(R,Thr,varargin)
//This function is meant for approximation. It takes real constant and real 
//polynomial matrix as input alongwith a constant 'Thr' which decides the 
//threshold value for approximation. All the coefficients of input R smaller 
//than threshold Thr are forced to zero. 3rd optional argument of function 
//('m'/'v') instucts if the magnitude or value of coefficients is to be looked
//at. Magnitude is considered by default.	//

//R can be a real matrix (constant or polynomial).	//
//Thr is a real constant number.	//
//varargin can be either 'm' or 'v'	//

[lhs,rhs]=argn(0)
if rhs~=2&rhs~=3 then
error('incorrect no. of input arguments to function ''abs_approx'' .')
end

if typeof(R)~='constant' & typeof(R)~='polynomial' then
error('Input must be a constant or polynomial matrix')
elseif any(any(real(R)-R~=0)) then
error('function ''abs_approx'' can not handle non-real input.')
end

if typeof(Thr)~='constant' then
error('input ''Thr'' to function ''abs_approx'' must be a constant.')
elseif any(size(Thr)~=[1,1]) then
error('input Thr to function ''abs_approx'' must be a scalar.')
elseif real(Thr)-Thr~=0 then
error('input Thr to function ''abs_approx'' must be a real number.')
end

if rhs==3 then
if typeof(varargin(1))=='string' then
if ~any(varargin(1)==['v','m']) then
error('the optional argument to function ''abs_approx'' must be either ''m'' or ''v''.')
end
else error('wrong type of optional argument to function ''abs_approx''.')
end
end


if typeof(R)=='polynomial' then
	v=varn(R)
	sr=size(R)
	//initialize aapR as zero matrix of size of R	//
	aapR=zeros(sr(1), sr(2))
	//for each entry of R, compare every coefficient with Thr, and 
	//keep only those which are greater than Thr.	//
	for j=1:sr(1)*sr(2),
	if rhs==3 then
		if varargin(1)=='v' then
		ncoeff=coeff(R(j)).*bool2s(coeff(R(j))>Thr)
		else ncoeff=coeff(R(j)).*bool2s(abs(coeff(R(j)))>Thr) 
		end
	else ncoeff=coeff(R(j)).*bool2s(abs(coeff(R(j)))>Thr)
	end
	aapR(j)=poly(ncoeff,v,'coeff')
	end

elseif typeof(R)=='constant' then
	sr=size(R)
	//initialize aapR as zero matrix of size of R	//
	aapR=zeros(sr(1), sr(2))
	//for each entry of R, compare every coefficient with Thr, and 
	//keep only those which are greater than Thr.	//
	for j=1:sr(1)*sr(2),
	if rhs==3 then
		if varargin(1)=='v' then
		nentry=R(j)*bool2s(R(j)>Thr)
		else nentry=R(j)*bool2s(abs(R(j))>Thr)
		end
	else nentry=R(j)*bool2s(abs(R(j))>Thr)
	end
	aapR(j)=nentry
	end
end

//end of function abs_approx	//

