function[flag,mdnnze,mdnnzi]=mdnnz(R,varargin)
//function mdnnz gives mdnnzi which is the index of first nonzero minimum degree 
//entry in R. mdnnze is that entry itself. If a scalar is given as second input argument, 
//it is treated as threshold and this function checks for the entry having atleast one 
//coefficient with absolute value larger than that of threshold. flag is 0 if none of the 
//minimum degree entries qualify this test. flag is 1 otherwise.	// 


[lhs,rhs]=argn(0)
if rhs~=1&rhs~=2 then
error('incorrect no. of input arguments to function ''mdnnz'' .')
end

if typeof(R)~='constant' & typeof(R)~='polynomial' then
error('Input must be a constant or polynomial matrix')
elseif any(any(real(R)-R~=0)) then
error('function ''mdnnz'' can not handle non-real input.')
end

if rhs==2 then
th=varargin(1)
if typeof(th)=='constant' then
 if size(th)==[1,1] then
  if real(th)-th==0 then
  else error('threshold ''th'' to function ''mdnnz'' can not be non-real.')
  end
 else error('threshold ''th'' to function ''mdnnz'' must be a scalar.')
 end
else error('threshold ''th'' to function ''mdnnz'' must be a constant.')
end
end


//form a vector (nz) having indices of nonzero elements of R	//
nz=find(R~=0)

//find index of first entry having minimum degree among these nonzero entries//
b=R(nz)
[m,n]=min(degree(b))

//determine index of this entry and the entry itself in R	//
mdnnzi=nz(n)
mdnnze=R(mdnnzi)
flag=1

if rhs==2 then
//set the flag depending on whether this entry has any coefficient greater than
//or equal to the threshold 	//
if abs(coeff(mdnnze))<=th ,x=0,else, x=1,i=mdnnzi ,end 
if x==0 then
	//get the indices of other elements of R having same degree as mdnz.
	n=find(degree(R)==degree(mdnnze))
	
	//check these elements one-by-one for anyone having atleast one
	//significant coeff.
	sn=size(n)
	for j=1:sn(2),
		if abs(coeff(R(n(j))))<=th ,
		x=0,else, x=1,i=n(j) ,break,end 
	end

	//if there is no element having significant coeff among the ones in
	//min. degree, find out one having the highest coeff among them.
	if x==0,	
	i=mdnnzi
		for j=1:sn(2),
			if max(coeff(R(n(j))))>max(coeff(R(i))),
			i=n(j), end
		end
	end
end	
flag=x
mdnnzi=i
mdnnze=R(mdnnzi)
end


//end of function mdnnz	//
