function[rk,rr,u,leftker,v]=polyrk2(R)
//given a polynomial matrix (R), this function computes its rank (rk), row echelong form
//(rr), the unimodular matrix (u) concerned with the row operations during reducing the 
//matrix R to itw row echelon form, and the algebraic left kernel (leftker) of input matrix (R).	//
//R== Input matrix (may be poly mtx.)
//rk is rank of R
//rr=row echelon form of R
//u=concerned unimodular matrix for row operations.
//v=concerned unimodular matrix for col. operations.
//leftker=algebraic kernel of R
//	OR,
// lower part of u which results in zero rows in R.	//

[lhs,rhs]=argn(0)
if rhs~=1 then
error('incorrect no. of input arguments to function ''polyrk'' .')
end

if typeof(R)~='constant' & typeof(R)~='polynomial' then
error('Input must be a constant or polynomial matrix')
elseif any(any(real(R)-R~=0)) then
error('function ''polyrk'' can not handle non-real input.')
end

//Now operate R in the following way, till last row/column of R is operated.	//

//initializing index of pivot element	//
i=1	//row index or pivot	//
[m,n] = size(R)

//define an identity matrix which becomes a unimodular matrix associated with the row 
//operations to be done on matrix R.	//
u=eye(m,m)
v=eye(n,n)
//do the following on each column of R or till last row is operated	//
for j=1:n	//for col.s 1 to n

//interchange 1st column of R with its column having minimum number of nonzeros.	//
numz=nmatch(R([i:$],[j:$]),0)
[maxz,maxzc]=max(numz)
R=colswap(R,j+maxzc-1,j)
v=colswap(v,j+maxzc-1,j)
  //in the matrix R, look at the partial column R([i+1:$],j), if there is any nonzero.
  cnz=find(R([i:$],j)~=0)
  //if there is any nonzero entry, do the following
  if cnz~=[] then
  pcnz=find(R([i+1:$],j)~=0)
		
  while pcnz~=[] then
  //break the loop if pivot is in last row already	//
  if i==m then break,end

	//Finding min. deg. nonzero element's index in R([i:$],j)
	//which does not vanish after being approximated.	//
	[flg,mdnnze,pc]=mdnnz(R([i:$],j),1e-7)	

	//if none of the min deg element is having a single significant
	//coeff., scale the whole pivot col./row if feasible.
	if flg==0 then
	  konst=scale(R(pc+i-1,j),'any','>1')
	  if any(coeff(konst*R([pc+i-1:$],j))>((10)^(150))) then flg=0 ,else flg=1 ,end
	//multiply the j-th column if scaling is feasible	//		
	  if flg==1 then
	  R(:,j)=R(:,j)*konst
	  u(:,j)=u(:,j)*konst
	  end
	end

	if flg==0 then
	  if any(coeff(konst*R(pc+i-1,[j:$]))>((10)^(150))) then flg=0 ,else flg=1 ,end
	 //multiply this candidate pivot row if scaling is feasible	//
  	  if flg==1 then
	  R(pc+i-1,:)=R(pc+i-1,:)*konst
	  u(pc+i-1,:)=u(pc+i-1,:)*konst
	  end
	end
	//force this min degree coeff.s in the j-th col. to zeros if scaling failed.	//
	if flg==0,R(:,j)=zeroing(R(:,j),degree(R(pc+i-1,j))),end
	
	//start operating on this j-th col, once we got a acceptable pivot. 
	if flg==1 then	

		//if pivot element is not the ith in col.-j then do row interchange
		//between row i and row p, in both R & u.	//
		if pc~=1 then
		p=pc-1+i
		R=rowswap(R,i,p)	
		u=rowswap(u,i,p)
		end	

		//approximate and condition the pivot column from pivot element onwards
		//to take care of round off errors occured earlier.	//	
		R([i:$],j)=abs_approx(rel_approx(R([i:$],j),(10)^(10)),1e-7,'m')

		//Parse the 2nd onwards entries of this partial column R([i:$],j) 
		//and do the following	//
		for e=(i+1):m
		
		  //replace the entries by the remainder of divison of this entry by pivot one	//
		  if R(e,j)~=0 then
		  [Rt,q]=pdiv2(R(e,j),R(i,j))
		  //approximate the remainder before replacing with R(e,j)	//	
		  Rtm=abs_approx(Rt,1e-7,'m')
		  R(e,j)=Rtm
 		  //do the same operations on the col.s of R on right of the pivot col.	//
		  if j~=n then
		  R(e,[j+1:$])=R(e,[j+1:$])-q*R(i,[j+1:$])
		  end
		  //do the same row operations on u	//
		  u(e,:)=u(e,:)-q*u(i,:)
 		  end
		end	
	end
  //refresh the partial pivot column for checking	//
  pcnz=find(R([i+1:$],j)~=0)
  ,end
  i=i+1,
  ;end
if i>m then break, end
,end

//define the row reduced matrix rr, compute the rank from looking at current value of i,
//and obtain the part of u which is representative matrix of kernel of input matrix R.	//
rr=R
rk=i-1
leftker=u([i:$],:)

//end of function polyrk 	//



