function[Rw]=projected(R,s,v)
//given the set of variables (s) and its representative matrix (R), this function pjn
//gives the representative matrix Rw for the subset of s indicated by vector v.
//s=set fo variables.
//R= repr mtx. for variables, s.
//v=indices of variables in s on which projection is desired	
//Rw=representative matrix of variables of s indicated by v

[lhs,rhs]=argn(0)
if rhs~=3 then
error('incorrect no. of input arguments to function ''pjn'' .')
end

if typeof(R)~='constant' & typeof(R)~='polynomial' then
error('Input must be a constant or polynomial matrix')
elseif any(any(real(R)-R~=0)) then
error('function ''polyrk'' can not handle non-real input.')
end

if typeof(s)=='constant' | typeof(s)=='string' then
if size(s,1)~=1 then
error('sequence ''s'' must be a row vector.')
elseif size(s,2)~=size(R,2) then
error('sequence ''s'' must be a row vector with as many entries as the no. of col.s in R.')
end
else error('sequence ''s'' must be constant or string.')
end

if typeof(v)=='constant' then
if real(v)==v & int(v)==v then
if any(v>size(s,1)*size(s,2)) | any(v<1) then
error('invalid indices in vector ''v''.')
end
else error('the vector ''v'' of indices of variables should be real integer only.')
end
else error('wrong type of vector ''v'' which should be ''constant'' only.')
end

//separate the columns associated with menifest variables and latent variables.	//
[Rsv,sn,Rl,Rr]=varshift(R,s,v)
R=Rl
Rw=Rr
//Now operate R & Rw both in the following way, till last row/column of R is operated.	//

//initializing index of pivot element	//
i=1	//row index of pivot	//
[m,n] = size(R)

//do the following on each column of R or till last row is operated	//
for j=1:n	

//interchange 1st column of R with its column having minimum number of nonzeros.	//
numz=nmatch(R([i:$],[j:$]),0)
[maxz,maxzc]=max(numz)
R=colswap(R,j+maxzc-1,j)

  //in the matrix R, look at the partial column R([i+1:$],j), if there is any nonzero.
  cnz=find(R([i:$],j)~=0)
  //if there is any nonzero entry, do the following
  if cnz~=[] then
  pcnz=find(R([i+1:$],j)~=0)
		
  while pcnz~=[] then
  //break the loop if pivot is in last row already	//
  if i==m then break,end

	//Find min. deg. nonzero element's index in R([i:$],j)
	//which does not vanish after being approximated.	//
	[flg,mdnnze,pc]=mdnnz(R([i:$],j),1e-7)
	
	//if none of the min deg element is having a single significant
	//coeff., scale the whole pivot col./row if feasible.
	if flg==0 then
	  konst=scale(R(pc+i-1,j),'any','>1')
	  if any(coeff(konst*R([pc+i-1:$],j))>((10)^(150))) then flg=0 ,else flg=1 ,end
	//multiply the j-th column if scaling is feasible	//		
	  if flg==1 then
	  R(:,j)=R(:,j)*konst
	  end
	end

	if flg==0 then
	  if any(coeff(konst*R(pc+i-1,[j:$]))>((10)^(150))) then flg=0 ,else flg=1 ,end
	 //multiply this candidate pivot row if scaling is feasible	//
  	  if flg==1 then
	  R(pc+i-1,:)=R(pc+i-1)*konst
	  end
	end

	//force this min degree coeff.s in the j-th col. to zeros if scaling failed.	//
	if flg==0,R(:,j)=zeroing(R(:,j),degree(R(pc+i-1,j))),end

  	//start operating on this j-th col, once we got a acceptable pivot. 
	if flg==1 then	

		//if pivot element is not the ith in col.-j then do row interchange
		//between row i and row p, both in R & Rw.	//
		if pc~=1 then
		p=pc-1+i
		R=rowswap(R,i,p)
		Rw=rowswap(Rw,i,p)
		end	

		//approximate and condition the pivot column from pivot element onwards
		//to take care of round off errors occured earlier.	//
	  	R([i:$],j)=abs_approx(rel_approx(R([i:$],j),(10)^(10)),1e-7,'m')

		//Parse the 2nd onwards entries of this partial column R([i:$],j) 
		//and do the following
		for e=(i+1):m

		  //replace the entries by the remainder of divison of this entry by pivot one	//
		  if R(e,j)~=0 then
		  [Rt,q]=pdiv2(R(e,j),R(i,j))
   		  //approximate the remainder before replacing with R(e,j)	//	
   		  Rtm=abs_approx(Rt,1e-7,'m')

 		  R(e,j)=Rtm
		  //do the same operations on the col.s of R on right of the pivot col.	//
 		  if j~=n then
		  R(e,[j+1:$])=R(e,[j+1:$])-q*R(i,[j+1:$])
		  end
		  //do the same row operations on Rw	//
		  Rw(e,:)=Rw(e,:)-q*Rw(i,:)
		  end
		end

	end;
  //refresh the partial pivot column for checking	//
  pcnz=find(R([i+1:$],j)~=0)
  end 	//ending while loop
  i=i+1,
  end			//ending if normc ~= 0
  if i>m then break, end
end

//obtain the representative matrix of projected variables	//
Rw=Rw([i:$],:)

//end of function pjn	//