function[rapR]=rel_approx(R,Thr)
//This function looks at every entry of R one by one. In every entry, all 
//those coefficients whose magnitude are smaller than the largest one, by 
//more than magnitude of threshold (Thr), are made zero. Naturally, output 
//is same as input for constant matrix R.//

//R=any polynomial (or constant) mtx .	//
//rapR=a mtx with each of entries of R approximated relatively in its own. 	//

[lhs,rhs]=argn(0)
if rhs~=2 then
error('incorrect no. of input arguments to function ''rel_approx'' .')
end

if typeof(R)~='constant' & typeof(R)~='polynomial' then
error('Input must be a constant or polynomial matrix')
elseif any(any(real(R)-R~=0)) then
error('function ''rel_approx'' can not handle non-real input.')
end

if typeof(Thr)~='constant' then
error('input ''Thr'' to function ''rel_approx'' must be a constant.')
elseif any(size(Thr)~=[1,1]) then
error('input Thr to function ''rel_approx'' must be a scalar.')
elseif abs(Thr)+Thr==0 then
warning('only absolute value of Thr is considered in ''rel_approx''.')
end

if typeof(R)=='polynomial' then
v=varn(R)
sr=size(R)
	//making a copy of R which will be transformed to 
	//conditioned R step by step.	//
rapR=R

for j=1:(sr(1)*sr(2)),
	//get the coeff of R(j), the entry under consideration in original
	// matrix and get the same in the copy of R.	//
	crj=coeff(R(j))
	ccrj=coeff(rapR(j))
	s=size(crj)
	//get the maximum of the coefficients for the entry under 
	//consideration	//
	hc=max(abs(crj))
	
	for jk=1:s(2),
	//look at the coefficients one by one and whenever its absolute value
	//is lesser than the highest absolute coefficient by more than 
	//absolute of threshold, force the corresponding coefficient in 
	//cr to zero.	//
		if crj(jk)~=0 then;
		if hc/abs(crj(jk))>abs(Thr) then
		ccrj(jk)=0
		end
		end
	end;
	//build up the corresponding entry of rapR with the new 
	//coefficients	//
	rapR(j)=poly(ccrj,v,'coeff')
end
//and if input is constant matrix, output is as same as input.	//
else rapR=R
end
//end of function rel_approx	//