.so ../sci.an
.SH NAME
polyrk2 - polynomial matrix rank.
.SH CALLING SEQUENCE
.nf
[rk,rr,u,leftker,v]=polyrk2(R)
.fi
.SH PARAMETERS
.TP 10
R
:  real matrix (constant or polynomial).
.TP 10
rk
: rank of R (number of linearly independent rows of R).
.TP 10
rr
: row echelon form of R.
.TP 10
u
: unimodular matrix concerned with the unimodular row operations done on R.
.TP 10
v
: unimodular matrix concerned with the unimodular column operations done on R.
.TP 10
leftker
: left kernel of R.
.SH DESCRIPTION
For a polynomial matrix R, this function gives number of linearly independent rows (rk), row
echelon form (rr), left kernel of R (leftker) and the unimodular matrix  (u) concerned with unimodular
row operations on R. This function differs from polyrk1 in the sense that this function does column 
operations also. Consequently giving an additional output v, s.t. rr=u*R*v.
.SH EXAMPLE
.nf
d=poly(0,'d')
//define a polynomial matrix, use polyrk2 and check the results.
R1=[1+d,8+d^2,d^3;4+d^3,5+d,d^3;3+d,7,7+d^4;2,8,6+d]
[rk1,rr1,u1,leftker1]=polyrk2(R1);
rk1,rr1,det(u1),max(coeff(leftker1*R1))
//another example
R2=[1+d,0,0;1,d,0;1,1,0]
[rk2,rr2,u2,leftker2]=polyrk2(R2);
rk2,rr2,det(u2),max(coeff(leftker2*R2))
//another example.
R3= [1/2+d, 1/3+d;1/7+d, 1/9+d]
[rk3,rr3,u3,leftker3]=polyrk2(R3);
rk3,rr3,det(u3)
.fi
.SH SEE ALSO
projected
.SH AUTHOR
S. S. K.


